### Name: opt.RW.mult
### Title: Functions to analyze multiple time-series jointly
### Aliases: opt.RW.mult logL.mult logL.sameMs logL.sameVs opt.RW.sameMs
###   opt.RW.sameVs
### Keywords: models ts

### ** Examples

 ## create two sequences, with different parameter values
 y1<- sim.rw(ns=20, sm=0, sv=1)
 y2<- sim.rw(ns=20, sm=0, sv=0.2)

 ## fit some models with at least some shared dynamics across sequences
 m1<- opt.RW.mult(list(y1,y2), model="RW")
 m2<- opt.RW.sameMs(list(y1, y2))
 m3<- opt.RW.sameVs(list(y1,y2))

 ## fit separate models to each sequence
 msep1<- opt.RW(y1)
 msep2<- opt.RW(y2)
 sep.logL<- msep1$value + msep2$value   # total logL sums across two solutions
 sep.aic <- -2*sep.logL + 2*4     # AIC of separate solutions

 ## check out resulting log-likelihoods and AIC values
 mres<- array(dim=c(4,2))
 row.names(mres)<- c("m1", "m2", "m3", "msep")
 colnames(mres)<- c("logL", "AIC")
 mres[1,]<- c(m1$value, m1$AIC)
 mres[2,]<- c(m2$value, m2$AIC)
 mres[3,]<- c(m3$value, m3$AIC)
 mres[4,]<- c(sep.logL, sep.aic)
 print (mres)



